@@ -96,6 +96,9 @@ static struct arg args[] = {
 { 's', "syslog", "use syslog for messages" },
 { INTARG | 'n', "nice", "set the process priority (see 'man nice')" },
 { 'c', "sched-idle", "set the process scheduling policy to idle (SCHED_IDLE)" },
+#ifdef HAVE_ALSA_USE_CASE_H
+{ 'D', "ucm-defaults", "execute also the UCM 'defaults' section" },
+#endif
 { HEADER, NULL, "Available commands:" },
 { CARDCMD, "store", "save current driver setup for one or each soundcards" },
 { EMPCMD, NULL, "  to configuration file" },
@@ -161,7 +164,7 @@ static void do_nice(int use_nice, int sched_idle)
 	if (sched_idle) {
 		if (sched_getparam(0, &sched_param) >= 0) {
 			sched_param.sched_priority = 0;
-			if (!sched_setscheduler(0, SCHED_IDLE, &sched_param))
+			if (sched_setscheduler(0, SCHED_IDLE, &sched_param) < 0)
 				error("sched_setparam failed: %s", strerror(errno));
 		} else {
 			error("sched_getparam failed: %s", strerror(errno));
@@ -191,6 +194,7 @@ int main(int argc, char *argv[])
 	int daemoncmd = 0;
 	int use_nice = NO_NICE;
 	int sched_idle = 0;
+	int initflags = 0;
 	struct arg *a;
 	struct option *o;
 	int i, j, k, res;
@@ -263,6 +267,9 @@ int main(int argc, char *argv[])
 		case 'I':
 			init_fallback = 0;
 			break;
+		case 'D':
+			initflags |= FLAG_UCM_DEFAULTS;
+			break;
 		case 'r':
 			statefile = optarg;
 			break;
@@ -354,8 +361,10 @@ int main(int argc, char *argv[])
 			syslog(LOG_INFO, "alsactl " SND_UTIL_VERSION_STR " daemon started");
 	}
 
+	snd_lib_error_set_handler(error_handler);
+
 	if (!strcmp(cmd, "init")) {
-		res = init(initfile, cardname);
+		res = init(initfile, initflags, cardname);
 		snd_config_update_free_global();
 	} else if (!strcmp(cmd, "store")) {
 		res = save_state(cfgfile, cardname);
@@ -364,7 +373,7 @@ int main(int argc, char *argv[])
 		   !strcmp(cmd, "nrestore")) {
 		if (removestate)
 			remove(statefile);
-		res = load_state(cfgfile, initfile, cardname, init_fallback);
+		res = load_state(cfgfile, initfile, initflags, cardname, init_fallback);
 		if (!strcmp(cmd, "rdaemon")) {
 			do_nice(use_nice, sched_idle);
 			res = state_daemon(cfgfile, cardname, period, pidfile);
