@@ -11,6 +11,7 @@ void info_(const char *fcn, long line, const char *fmt, ...);
 void error_(const char *fcn, long line, const char *fmt, ...);
 void cerror_(const char *fcn, long line, int cond, const char *fmt, ...);
 void dbg_(const char *fcn, long line, const char *fmt, ...);
+void error_handler(const char *file, int line, const char *function, int err, const char *fmt, ...);
 
 #if __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 95)
 #define info(...) do { info_(__func__, __LINE__, __VA_ARGS__); } while (0)
@@ -24,12 +25,15 @@ void dbg_(const char *fcn, long line, const char *fmt, ...);
 #define dbg(args...) do { dbg_(__func__, __LINE__, ##args); }  while (0)
 #endif	
 
-int init(const char *file, const char *cardname);
+#define FLAG_UCM_DEFAULTS	(1<<0)
+
+int init(const char *file, int flags, const char *cardname);
+int init_ucm(int flags, int cardno);
 int state_lock(const char *file, int timeout);
 int state_unlock(int fd, const char *file);
 int save_state(const char *file, const char *cardname);
-int load_state(const char *file, const char *initfile, const char *cardname,
-	       int do_init);
+int load_state(const char *file, const char *initfile, int initflags,
+	       const char *cardname, int do_init);
 int power(const char *argv[], int argc);
 int monitor(const char *name);
 int state_daemon(const char *file, const char *cardname, int period,
