@@ -1742,10 +1742,10 @@ static int parse(struct space *space, const char *filename)
 	return err ? err : -abs(space->exit_code);
 }
 
-int init(const char *filename, const char *cardname)
+int init(const char *filename, int flags, const char *cardname)
 {
 	struct space *space;
-	int err = 0, card, first;
+	int err = 0, lasterr = 0, card, first;
 	
 	sysfs_init();
 	if (!cardname) {
@@ -1762,22 +1762,34 @@ int init(const char *filename, const char *cardname)
 				break;
 			}
 			first = 0;
+			err = init_ucm(flags, card);
+			if (err == 0)
+				continue;
 			err = init_space(&space, card);
 			if (err == 0) {
 				space->rootdir = new_root_dir(filename);
 				if (space->rootdir != NULL)
 					err = parse(space, filename);
+				if (err <= -99) { /* non-fatal errors */
+					if (lasterr == 0)
+						lasterr = err;
+					err = 0;
+				}
 				free_space(space);
 			}
 			if (err < 0)
 				break;
 		}
+		err = lasterr;
 	} else {
 		card = snd_card_get_index(cardname);
 		if (card < 0) {
 			error("Cannot find soundcard '%s'...", cardname);
 			goto error;
 		}
+		err = init_ucm(flags, card);
+		if (err == 0)
+			return 0;
 		memset(&space, 0, sizeof(space));
 		err = init_space(&space, card);
 		if (err == 0) {
